@@ -13,10 +13,10 @@
 #' @examples
 #' itrax_correlation(CD166_19_S1$xrf, plot = TRUE)
 #'
-#' @importFrom stats cor na.omit
+#' @importFrom stats na.omit
+#' @importFrom compositions cor
 #' @importFrom utils data
 #' @importFrom ggcorrplot ggcorrplot cor_pmat
-#' @importFrom tibble column_to_rownames
 #' @export
 
 itrax_correlation = function(dataframe,
@@ -26,38 +26,30 @@ itrax_correlation = function(dataframe,
                              plot = FALSE){
 
   # fudge to stop check notes
-  . = NULL
-  group = NULL
-  ids = NULL
-  position = NULL
 
   # label with ids
-  dataframe$ids <- 1:dim(dataframe)[1]
-  input_dataframe <- dataframe
+  dataframe <- dataframe %>%
+    uid_labeller()
 
   # use internal function to do multivariate data preparation
-  dataframe <- multivariate_import(dataframe = dataframe,
-                                   elementsonly = elementsonly,
-                                   zeros = zeros,
-                                   transform = transform)
-
-  # save the ids
-  input_ids <- dataframe$ids
+  input_dataframe <- multivariate_import(dataframe = dataframe,
+                                         elementsonly = elementsonly,
+                                         zeros = zeros,
+                                         transform = transform)
 
   # run the correlation matrix
   # in time, I'll add confidence levels to this
 
-  cor_matrix <- dataframe %>%
-    tibble::column_to_rownames(var = "ids") %>%
-    cor(use = "pairwise.complete.obs",
-        method = "pearson")
+  cor_matrix <- input_dataframe %>%
+    compositions::cor(use = "pairwise.complete.obs",
+                      method = "pearson")
 
   # draw a summary diagram if required
   # make a plot if required
   if(is.logical(plot) == TRUE && plot == TRUE){
     print(ggcorrplot::ggcorrplot(cor_matrix,
                                  hc.order = TRUE,
-                                 p.mat = cor_pmat(cor_matrix, method = "spearman"),
+                                 p.mat = ggcorrplot::cor_pmat(cor_matrix, method = "spearman"),
                                  insig = "blank"))
   } else if(is.logical(plot) == FALSE){
     stop("plot parameter must be logical (TRUE/FALSE)")
